# Ordinal-Scale-Stats-py

Python package that helps you analyze ordinal data.

## Introduction

Ordinal scale data is common. Companies and governments can quickly perform large-scale research with surveys.
Usually, a survey output is placed on the Likert scale, where answers are ordered to describe a person's feelings about the survey's topic.
A typical example of a survey is when a person is asked to agree with a statement with answers on a five-level scale:

```text
Should the law protect your personal data?

1. Strongly disagree.
2. Rather disagree.
3. I don't know.
4. Rather agree.
5. Strongly agree.
```

The order between categories makes analysis complex, and the fact that answers are polarized between opposing states. Moreover, a border between categories is subjective and depends on the person's experiences, feelings, and knowledge about a surveying topic.

Classical measurements of central tendency do not fit well with ordinal data [ADD BIBLIOGRAPHY]. We encourage you to use the `ordinal-scale-stats` package to analyze survey responses.
With `ordinal-scale-stats`, you can:

- visualize differences between surveyed groups,
- measure polarization *within* a group,
- measure polarization *between* groups,
- measure ...

## Example use case

## Setup

## Requirements

## API

## Vignettes

## Tests and Contribution

## Community

## Citation
